@@ -27,6 +27,7 @@ usage: cb-ctl -h | --help
            [--timeout=<time_sec>]
        cb-ctl --build-dependencies-local (--dist=<name>|--selection=<name>)
        cb-ctl --build-log=<package│image> --project-path=<path> --arch=<name> (--dist=<name>|--selection=<name>)
+           [--keep-open]
            [--timeout=<time_sec>]
        cb-ctl --build-info=<package│image> --project-path=<path> --arch=<name> (--dist=<name>|--selection=<name>)
            [--timeout=<time_sec>]
@@ -122,6 +123,9 @@ options:
     --clean
         Delete package buildroot if present on the runner
         before building the package
+
+    --keep-open
+        Use tail -f to open the log file on the runner
 """
 import time
 import os
@@ -233,6 +237,7 @@ def main() -> None:
             args['--dist'],
             args['--selection'],
             int(args['--timeout'] or default_timeout),
+            args['--keep-open'],
             get_config()
         )
     elif args['--build-info']:
@@ -394,7 +399,7 @@ def get_build_dependencies(
 ) -> None:
     solver_data = _get_info_response_file(
         broker, target, project_path, arch, dist, selection,
-        timeout_sec, config, 'solver_file'
+        timeout_sec, config, 'dependencies'
     )
     if solver_data:
         CBDisplay.print_json(json.loads(solver_data))
@@ -430,11 +435,12 @@ def get_build_dependencies_local(dist: str, selection_name: str) -> None:
 
 def get_build_log(
     broker: Any, target: str, project_path: str, arch: str,
-    dist: str, selection: str, timeout_sec: int, config: Dict
+    dist: str, selection: str, timeout_sec: int, keep_open: bool,
+    config: Dict
 ) -> None:
     build_log_data = _get_info_response_file(
         broker, target, project_path, arch, dist, selection,
-        timeout_sec, config, 'log_file'
+        timeout_sec, config, 'logs', keep_open
     )
     if build_log_data:
         CBDisplay.print_raw(build_log_data)
@@ -549,27 +555,77 @@ def get_info(
 def _get_info_response_file(
     broker: Any, target: str, project_path: str, arch: str,
     dist: str, selection: str, timeout_sec: int,
-    config: Dict, response_file_name
+    config: Dict, response_file_id: str, keep_open: bool = False
 ) -> str:
     info_response = get_info(
         broker, target, project_path, arch, dist, selection, timeout_sec
     )
     if info_response:
-        response_file = info_response[response_file_name]
         runner_ip = info_response['source_ip']
         ssh_user = config['runner']['ssh_user']
         ssh_pkey_file = config['runner']['ssh_pkey_file']
-        return Command.run(
-            [
-                'ssh', '-i', ssh_pkey_file,
-                '-o', 'StrictHostKeyChecking=accept-new',
-                f'{ssh_user}@{runner_ip}',
-                'cat', response_file
-            ]
-        ).output
+        ssh_runner = [
+            'ssh', '-i', ssh_pkey_file,
+            '-o', 'StrictHostKeyChecking=accept-new',
+            f'{ssh_user}@{runner_ip}'
+        ]
+        response_file_list = []
+        if response_file_id == 'logs' and selection:
+            # image build log
+            build_log_file = _get_file_from_response(
+                info_response, 'log_file'
+            )
+            if build_log_file:
+                response_file_list.append(build_log_file)
+        elif response_file_id == 'logs' and dist:
+            # package build logs
+            prepare_log_file = _get_file_from_response(
+                info_response, 'prepare_log_file'
+            )
+            if prepare_log_file:
+                response_file_list.append(prepare_log_file)
+            build_log_file = _get_file_from_response(
+                info_response, 'log_file'
+            )
+            if build_log_file:
+                response_file_list.append(build_log_file)
+        elif response_file_id == 'dependencies':
+            # image or package build dependencies
+            solver_log_file = _get_file_from_response(
+                info_response, 'solver_file'
+            )
+            if solver_log_file:
+                response_file_list.append(solver_log_file)
+
+        if response_file_list:
+            if not keep_open:
+                return Command.run(
+                    ssh_runner + [
+                        'cat'
+                    ] + response_file_list
+                ).output
+            else:
+                os.system(
+                    ' '.join(
+                        ssh_runner + [
+                            'tail', '-f',
+                        ] + response_file_list
+                    )
+                )
     return ''
 
 
+def _get_file_from_response(info_response: Dict, name: str) -> str:
+    if name == 'prepare_log_file':
+        filename = info_response['package'][name]
+    else:
+        filename = info_response[name]
+    if filename == 'none':
+        log.warning(f'Response record has no information for: {name}')
+        filename = ''
+    return filename
+
+
 def _response_reader(
     broker: Any, timeout_sec: int, func: Callable
 ) -> None:
